@@ -1,5 +1,3 @@
 from .parser import NestedParser
 
-__all__ = [
-    'NestedParser'
-]
+__all__ = ["NestedParser"]
